import sys
import webbrowser
import itertools
import threading
from time import sleep
from arguments import arguments
from searchpie.searchpie import SearchPie

Done = False


def animation():
    global Done
    Done = False
    for c in itertools.cycle(["⢿", "⣻", "⣽", "⣾", "⣷", "⣯", "⣟", "⡿"]):
        if Done:
            break
        sys.stdout.write('\r' + c + " Searching...")
        sys.stdout.flush()
        sleep(0.1)


def main():
    global Done
    try:
        args = arguments()
        pie = SearchPie(args)
        if args is None:
            return
        elif args.default is True:
            print("Valid Default Params: " + ", ".join(["wiki", "movie", "tv", "anime", "manga"]))
            default = input("Enter Param: ")
            pie.default = default
            return
        elif args.key is not None and args.key != '':
            pie.api_key = args.key
            return
        elif args.show_def is True:
            print(pie.default)
            return
        t = threading.Thread(target=animation)
        t.start()
        data = pie.parser()
        Done = True
        print('\x1b[1K\r')

        if args.browser is True:
            webbrowser.open(data[0].url, new=2)
            return

        data = data[:int(args.pages)]
        for i in data:
            if args.all is True and i.identifier_type == "wiki":
                i.identifier_type = "all_wiki"
            print(i)
            if len(data) > 1:
                print("\n")
    except Exception as e:
        Done = True
        print('\x1b[1K\r')
        print(str(e))


if __name__ == '__main__':
    main()



import requests
from .helpers.DataClass import dataclass


class WIKI:

    def __init__(self, query: str):
        self.query = query
        self.search = "https://en.wikipedia.org/w/api.php?action=opensearch&search={}&limit=1&format=json"
        self.page = "https://en.wikipedia.org/w/api.php?action=query&prop=extracts&exlimit=1&titles={}&explaintext=1&exsectionformat=plain&format=json"

    @staticmethod
    def sendRequest(url):
        return requests.get(url).json()

    def url_builder(self, query: str, base_url: str):
        query = query.replace(" ", "+")
        return base_url.format(query)

    def _call(self, result):
        if self.query == [] or self.query == '' or self.query is None:
            raise WikiExceptions("Empty query")
        if result is None or result == []:
            raise WikiExceptions(f"There are no results that matched \"{self.query}\"")
        if type(result) is list and result[1] == []:
            raise WikiExceptions(f"There are no results that matched \"{self.query}\"")
        if result is int and result == -1:
            raise WikiExceptions(f"No page exists for \"{self.query}\" ")

    def result(self):
        search = self.sendRequest(self.url_builder(self.query, self.search))
        self._call(search)
        page_id = search[1][0]
        page = self.sendRequest(self.url_builder(page_id, self.page))
        self._call(page)
        page = page["query"]["pages"]

        for i in page:
            self._call(i)
            page = page[i]
        wiki = dataclass()
        wiki.identifier_type = "wiki"
        wiki.title = page['title'].replace(" ", "_")
        wiki.synopsis = page['extract']
        wiki.url = "https://en.wikipedia.org/wiki/{}".format(wiki.title)

        return [wiki]


class WikiExceptions(Exception):
    pass



from setuptools import setup
from src._version import __version__

setup(
    name='searchpie',
    version=__version__,
    author='Gautam Dhingra',
    author_email="gautamdhingra8404@gmail.com",
    download_url='http://pypi.python.org/pypi/searchpie',
    description='A handy tool to search through Wikipedia, Tmdb and Mal.',
    long_description=open("README.md").read(),
    long_description_content_type='text/markdown',
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    project_urls={
        "Source": "https://github.com/gautam8404/Searchpie"
    },
    install_requires=[
        'requests'
    ],
    entry_points={
        'console_scripts': ['searchpie=main:main']
    },
    python_requires='>=3.5'
)



import os
import json
from .functions.mal import MAL
from .functions.tmdb import TMDB
from .functions.wiki import WIKI


class SearchPie:
    abs_path = os.path.dirname(os.path.abspath(__file__))
    _path = os.path.join(abs_path, 'data/configure.json')

    def __init__(self, args):
        self.args = args

    def _call(self, method: str):
        if method not in ["wiki", "movie", "tv", "anime", "manga"]:
            raise SearchPieExceptions("Invalid Default Method")

    @property
    def api_key(self):
        with open(self._path, "r") as file:
            api_key_dict = json.load(file)
        return api_key_dict["api_key"]

    @api_key.setter
    def api_key(self, key: str):
        with open(self._path, "r") as file:
            key_dict = json.load(file)

        key_dict["api_key"] = key
        with open(self._path, "w") as wfile:
            json.dump(key_dict, wfile, indent=4)

    @property
    def default(self):
        with open(self._path, "r") as file:
            api_key_dict = json.load(file)
        return api_key_dict["default"]

    @default.setter
    def default(self, default_method: str):
        self._call(default_method)
        with open(self._path, "r") as file:
            key_dict = json.load(file)

        key_dict["default"] = default_method
        with open(self._path, "w") as wfile:
            json.dump(key_dict, wfile, indent=4)

    def method_parser(self, method: str, query: list):
        self._call(method)
        query = " ".join(query)
        if method == "wiki":
            w = WIKI(query)
            return w.result()
        elif method == "movie":
            m = TMDB(self.api_key)
            return m.Movie(query)
        elif method == "tv":
            t = TMDB(self.api_key)
            return t.Tv(query)
        elif method == "anime":
            a = MAL()
            return a.anime(query)
        elif method == "manga":
            manga = MAL()
            return manga.manga(query)

    def parser(self):
        args = self.args
        if args.default_method is not None and args.default_method != []:
            return self.method_parser(self.default, args.default_method)
        elif args.anime is not None and args.anime != []:
            return self.method_parser("anime", args.anime)
        elif args.manga is not None and args.manga != []:
            return self.method_parser("manga", args.manga)
        elif args.movie is not None and args.movie != []:
            return self.method_parser("movie", args.movie)
        elif args.tv is not None and args.tv != []:
            return self.method_parser("tv", args.tv)
        elif args.wiki is not None and args.wiki != []:
            return self.method_parser("wiki", args.wiki)


class SearchPieExceptions(Exception):
    pass
